/* Blog layout: Custom
------------------------- */

@import "../../../../css/_mixins.scss";
@import "../../../../css/_theme-vars.scss";
@import "../../css/_skin-vars.scss";

.post_layout_custom {
	position:relative;
}
.post_layout_custom .post_featured[class*="hover_"] {
	display: block;
}
.post_layout_custom .post_featured img {
	width: 100%;
}
.post_layout_custom .post_header {
	padding-top:0.02px;	  // Incapsulate margins inside the block without 'overflow: hidden'
}
