<?php
/**
 * The template to display 'No posts' part
 *
 * @package ThemeREX Addons
 * @since v1.6.22
 */
?><div class="trx_addons_no_posts">
	<h2 class="trx_addons_no_posts_title"><?php esc_html_e('No posts found on your query!', 'trx_addons'); ?></h2>
	<h5 class="trx_addons_no_posts_subtitle"><?php esc_html_e('Try again with different parameters ...', 'trx_addons'); ?></h5>
</div>