<?php
/**
 * The Classic template to display the content
 *
 * Used for index/archive/search.
 *
 * @package PANTRY
 * @since PANTRY 1.0
 */

$pantry_template_args = get_query_var( 'pantry_template_args' );

if ( is_array( $pantry_template_args ) ) {
	$pantry_columns    = empty( $pantry_template_args['columns'] ) ? 2 : max( 1, $pantry_template_args['columns'] );
	$pantry_blog_style = array( $pantry_template_args['type'], $pantry_columns );
    $pantry_columns_class = pantry_get_column_class( 1, $pantry_columns, ! empty( $pantry_template_args['columns_tablet']) ? $pantry_template_args['columns_tablet'] : '', ! empty($pantry_template_args['columns_mobile']) ? $pantry_template_args['columns_mobile'] : '' );
} else {
	$pantry_template_args = array();
	$pantry_blog_style = explode( '_', pantry_get_theme_option( 'blog_style' ) );
	$pantry_columns    = empty( $pantry_blog_style[1] ) ? 2 : max( 1, $pantry_blog_style[1] );
    $pantry_columns_class = pantry_get_column_class( 1, $pantry_columns );
}
$pantry_expanded   = ! pantry_sidebar_present() && pantry_get_theme_option( 'expand_content' ) == 'expand';

$pantry_post_format = get_post_format();
$pantry_post_format = empty( $pantry_post_format ) ? 'standard' : str_replace( 'post-format-', '', $pantry_post_format );

?><div class="<?php
	if ( ! empty( $pantry_template_args['slider'] ) ) {
		echo ' slider-slide swiper-slide';
	} else {
		echo ( pantry_is_blog_style_use_masonry( $pantry_blog_style[0] ) ? 'masonry_item masonry_item-1_' . esc_attr( $pantry_columns ) : esc_attr( $pantry_columns_class ) );
	}
?>"><article id="post-<?php the_ID(); ?>" data-post-id="<?php the_ID(); ?>"
	<?php
	post_class(
		'post_item post_item_container post_format_' . esc_attr( $pantry_post_format )
				. ' post_layout_classic post_layout_classic_' . esc_attr( $pantry_columns )
				. ' post_layout_' . esc_attr( $pantry_blog_style[0] )
				. ' post_layout_' . esc_attr( $pantry_blog_style[0] ) . '_' . esc_attr( $pantry_columns )
	);
	pantry_add_blog_animation( $pantry_template_args );
	?>
>
	<?php

	// Sticky label
	if ( is_sticky() && ! is_paged() ) {
		?>
		<span class="post_label label_sticky"></span>
		<?php
	}

	// Featured image
	$pantry_hover      = ! empty( $pantry_template_args['hover'] ) && ! pantry_is_inherit( $pantry_template_args['hover'] )
							? $pantry_template_args['hover']
							: pantry_get_theme_option( 'image_hover' );

	$pantry_components = ! empty( $pantry_template_args['meta_parts'] )
							? ( is_array( $pantry_template_args['meta_parts'] )
								? $pantry_template_args['meta_parts']
								: explode( ',', $pantry_template_args['meta_parts'] )
								)
							: pantry_array_get_keys_by_value( pantry_get_theme_option( 'meta_parts' ) );

	pantry_show_post_featured( apply_filters( 'pantry_filter_args_featured',
		array(
			'thumb_size' => ! empty( $pantry_template_args['thumb_size'] )
				? $pantry_template_args['thumb_size']
				: pantry_get_thumb_size(
					'classic' == $pantry_blog_style[0]
						? ( strpos( pantry_get_theme_option( 'body_style' ), 'full' ) !== false
								? ( $pantry_columns > 2 ? 'big' : 'huge' )
								: ( $pantry_columns > 2
									? ( $pantry_expanded ? 'square' : 'square' )
									: ($pantry_columns > 1 ? 'square' : ( $pantry_expanded ? 'huge' : 'big' ))
									)
							)
						: ( strpos( pantry_get_theme_option( 'body_style' ), 'full' ) !== false
								? ( $pantry_columns > 2 ? 'masonry-big' : 'full' )
								: ($pantry_columns === 1 ? ( $pantry_expanded ? 'huge' : 'big' ) : ( $pantry_columns <= 2 && $pantry_expanded ? 'masonry-big' : 'masonry' ))
							)
			),
			'hover'      => $pantry_hover,
			'meta_parts' => $pantry_components,
			'no_links'   => ! empty( $pantry_template_args['no_links'] ),
        ),
        'content-classic',
        $pantry_template_args
    ) );

	// Title and post meta
	$pantry_show_title = get_the_title() != '';
	$pantry_show_meta  = count( $pantry_components ) > 0 && ! in_array( $pantry_hover, array( 'border', 'pull', 'slide', 'fade', 'info' ) );

	if ( $pantry_show_title ) {
		?>
		<div class="post_header entry-header">
			<?php

			// Post meta
			if ( apply_filters( 'pantry_filter_show_blog_meta', $pantry_show_meta, $pantry_components, 'classic' ) ) {
				if ( count( $pantry_components ) > 0 ) {
					do_action( 'pantry_action_before_post_meta' );
					pantry_show_post_meta(
						apply_filters(
							'pantry_filter_post_meta_args', array(
							'components' => join( ',', $pantry_components ),
							'seo'        => false,
							'echo'       => true,
						), $pantry_blog_style[0], $pantry_columns
						)
					);
					do_action( 'pantry_action_after_post_meta' );
				}
			}

			// Post title
			if ( apply_filters( 'pantry_filter_show_blog_title', true, 'classic' ) ) {
				do_action( 'pantry_action_before_post_title' );
				if ( empty( $pantry_template_args['no_links'] ) ) {
					the_title( sprintf( '<h4 class="post_title entry-title"><a href="%s" rel="bookmark">', esc_url( get_permalink() ) ), '</a></h4>' );
				} else {
					the_title( '<h4 class="post_title entry-title">', '</h4>' );
				}
				do_action( 'pantry_action_after_post_title' );
			}

			if( !in_array( $pantry_post_format, array( 'quote', 'aside', 'link', 'status' ) ) ) {
				// More button
				if ( apply_filters( 'pantry_filter_show_blog_readmore', ! $pantry_show_title || ! empty( $pantry_template_args['more_button'] ), 'classic' ) ) {
					if ( empty( $pantry_template_args['no_links'] ) ) {
						do_action( 'pantry_action_before_post_readmore' );
						pantry_show_post_more_link( $pantry_template_args, '<div class="more-wrap">', '</div>' );
						do_action( 'pantry_action_after_post_readmore' );
					}
				}
			}
			?>
		</div><!-- .entry-header -->
		<?php
	}

	// Post content
	if( in_array( $pantry_post_format, array( 'quote', 'aside', 'link', 'status' ) ) ) {
		ob_start();
		if (apply_filters('pantry_filter_show_blog_excerpt', empty($pantry_template_args['hide_excerpt']) && pantry_get_theme_option('excerpt_length') > 0, 'classic')) {
			pantry_show_post_content($pantry_template_args, '<div class="post_content_inner">', '</div>');
		}
		// More button
		if(! empty( $pantry_template_args['more_button'] )) {
			if ( empty( $pantry_template_args['no_links'] ) ) {
				do_action( 'pantry_action_before_post_readmore' );
				pantry_show_post_more_link( $pantry_template_args, '<div class="more-wrap">', '</div>' );
				do_action( 'pantry_action_after_post_readmore' );
			}
		}
		$pantry_content = ob_get_contents();
		ob_end_clean();
		pantry_show_layout($pantry_content, '<div class="post_content entry-content">', '</div><!-- .entry-content -->');
	}
	?>

</article></div><?php
// Need opening PHP-tag above, because <div> is a inline-block element (used as column)!
