<?php
/**
 * The template to display the socials in the footer
 *
 * @package PANTRY
 * @since PANTRY 1.0.10
 */


// Socials
if ( pantry_is_on( pantry_get_theme_option( 'socials_in_footer' ) ) ) {
	$pantry_output = pantry_get_socials_links();
	if ( '' != $pantry_output ) {
		?>
		<div class="footer_socials_wrap socials_wrap">
			<div class="footer_socials_inner">
				<?php pantry_show_layout( $pantry_output ); ?>
			</div>
		</div>
		<?php
	}
}
