<h1>Exclude Sources</h1>		
<p>If you want some of the sources NOT to be served via CDN, you can specify the sources. If a source url contains any keyword below, it is NOT served via CDN.</p>
<div class="wiz-input-cont" style="padding:8px 18px;border-radius:0;text-align:center; background: #fff none repeat scroll 0 0;">
	
	<style type="text/css">
		.keyword-item-exclude{width:auto;float:left;line-height:22px;position:relative;background:rgba(0,0,0,0.15);margin:0 5px 5px 0;-webkit-border-radius:3px;-moz-border-radius:3px;border-radius:3px;}
		.keyword-item-exclude a.keyword-label{
			background-color: #ffa100;
			color:#ffffff;
			text-decoration:none;
			padding:7px 15px;
			display:block;
			text-shadow:none;
			-webkit-transition:all .1s linear;
			-moz-transition:all .1s linear;
			-o-transition:all .1s linear;
			transition:all .1s linear;
			cursor: pointer;
		}
		.keyword-item-exclude a.keyword-label:hover{
			padding-left: 4px;
			padding-right: 26px;
		}
		.keyword-item-exclude a.keyword-label:hover:after{
			width:16px;
			height:16px;
			background-image: url('data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAQAAAC1+jfqAAAAAnNCSVQICFXsRgQAAAAJcEhZcwAAAIAAAACAAc9WmjcAAAAZdEVYdFNvZnR3YXJlAHd3dy5pbmtzY2FwZS5vcmeb7jwaAAAA4klEQVQokWXOMSuFcRQH4EcZZFB3w0BZfIC7mLl3MaGu2cAtqyLJwMQiRuObidFG4hNQJrlFJBlMFgzKMfi/vPe9/ZbT+T11jvAbq2nI8k3aB1MymStPTrTcyWTmi2BDdCQrgprtjjQKIJgw15aZth+Co9KB6zLYL4GLMthqq7/slcFKoVzTa1ClHTT/wKwxt0I4N/wPGqk+NuTNqQ/PLt3oyUEtgQWbQl3NqHVhOgfVBCYdCC3dhnwKSzkYSWDXslDVNG5RqOegksCDPg/ufXv34kxXAkF/SpcBh1492tEbwg+6YscxiN7TegAAAABJRU5ErkJggg==');
			content:"";
			position:absolute;
			top:10px;
			right:4px;
		}



	</style>
	
	<ul class="keyword-item-list">
        <li class="keyword-item-exclude">
            <a class="wpfc-add-new-keyword">Add Keyword</a>
            <div class="wpfc-textbox-con" style="display:none;">
                <div class="fixed-search"><input type="text" placeholder="Add Keyword"></div>
            </div>
        </li>
    </ul>
</div>