<?php
/**
 * The template to display Admin notices
 *
 * @package PANTRY
 * @since PANTRY 1.0.1
 */

$pantry_theme_slug = get_option( 'template' );
$pantry_theme_obj  = wp_get_theme( $pantry_theme_slug );
?>
<div class="pantry_admin_notice pantry_welcome_notice notice notice-info is-dismissible" data-notice="admin">
	<?php
	// Theme image
	$pantry_theme_img = pantry_get_file_url( 'screenshot.jpg' );
	if ( '' != $pantry_theme_img ) {
		?>
		<div class="pantry_notice_image"><img src="<?php echo esc_url( $pantry_theme_img ); ?>" alt="<?php esc_attr_e( 'Theme screenshot', 'pantry' ); ?>"></div>
		<?php
	}

	// Title
	?>
	<h3 class="pantry_notice_title">
		<?php
		echo esc_html(
			sprintf(
				// Translators: Add theme name and version to the 'Welcome' message
				__( 'Welcome to %1$s v.%2$s', 'pantry' ),
				$pantry_theme_obj->get( 'Name' ) . ( PANTRY_THEME_FREE ? ' ' . __( 'Free', 'pantry' ) : '' ),
				$pantry_theme_obj->get( 'Version' )
			)
		);
		?>
	</h3>
	<?php

	// Description
	?>
	<div class="pantry_notice_text">
		<p class="pantry_notice_text_description">
			<?php
			echo str_replace( '. ', '.<br>', wp_kses_data( $pantry_theme_obj->description ) );
			?>
		</p>
		<p class="pantry_notice_text_info">
			<?php
			echo wp_kses_data( __( 'Attention! Plugin "ThemeREX Addons" is required! Please, install and activate it!', 'pantry' ) );
			?>
		</p>
	</div>
	<?php

	// Buttons
	?>
	<div class="pantry_notice_buttons">
		<?php
		// Link to the page 'About Theme'
		?>
		<a href="<?php echo esc_url( admin_url() . 'themes.php?page=pantry_about' ); ?>" class="button button-primary"><i class="dashicons dashicons-nametag"></i> 
			<?php
			echo esc_html__( 'Install plugin "ThemeREX Addons"', 'pantry' );
			?>
		</a>
	</div>
</div>
