<?php
/**
 * The default template to display the content
 *
 * Used for index/archive/search.
 *
 * @package PANTRY
 * @since PANTRY 1.0
 */

$pantry_template_args = get_query_var( 'pantry_template_args' );
$pantry_columns = 1;
if ( is_array( $pantry_template_args ) ) {
	$pantry_columns    = empty( $pantry_template_args['columns'] ) ? 1 : max( 1, $pantry_template_args['columns'] );
	$pantry_blog_style = array( $pantry_template_args['type'], $pantry_columns );
	if ( ! empty( $pantry_template_args['slider'] ) ) {
		?><div class="slider-slide swiper-slide">
		<?php
	} elseif ( $pantry_columns > 1 ) {
	    $pantry_columns_class = pantry_get_column_class( 1, $pantry_columns, ! empty( $pantry_template_args['columns_tablet']) ? $pantry_template_args['columns_tablet'] : '', ! empty($pantry_template_args['columns_mobile']) ? $pantry_template_args['columns_mobile'] : '' );
		?>
		<div class="<?php echo esc_attr( $pantry_columns_class ); ?>">
		<?php
	}
} else {
	$pantry_template_args = array();
}
$pantry_expanded    = ! pantry_sidebar_present() && pantry_get_theme_option( 'expand_content' ) == 'expand';
$pantry_post_format = get_post_format();
$pantry_post_format = empty( $pantry_post_format ) ? 'standard' : str_replace( 'post-format-', '', $pantry_post_format );
?>
<article id="post-<?php the_ID(); ?>" data-post-id="<?php the_ID(); ?>"
	<?php
	post_class( 'post_item post_item_container post_layout_excerpt post_format_' . esc_attr( $pantry_post_format ) );
	pantry_add_blog_animation( $pantry_template_args );
	?>
>
	<?php

	// Sticky label
	if ( is_sticky() && ! is_paged() ) {
		?>
		<span class="post_label label_sticky"></span>
		<?php
	}

	// Featured image
	$pantry_hover      = ! empty( $pantry_template_args['hover'] ) && ! pantry_is_inherit( $pantry_template_args['hover'] )
							? $pantry_template_args['hover']
							: pantry_get_theme_option( 'image_hover' );
	$pantry_components = ! empty( $pantry_template_args['meta_parts'] )
							? ( is_array( $pantry_template_args['meta_parts'] )
								? $pantry_template_args['meta_parts']
								: array_map( 'trim', explode( ',', $pantry_template_args['meta_parts'] ) )
								)
							: pantry_array_get_keys_by_value( pantry_get_theme_option( 'meta_parts' ) );
	pantry_show_post_featured( apply_filters( 'pantry_filter_args_featured',
		array(
			'no_links'   => ! empty( $pantry_template_args['no_links'] ),
			'hover'      => $pantry_hover,
			'meta_parts' => $pantry_components,
			'thumb_size' => ! empty( $pantry_template_args['thumb_size'] )
							? $pantry_template_args['thumb_size']
							: pantry_get_thumb_size( strpos( pantry_get_theme_option( 'body_style' ), 'full' ) !== false
								? 'full'
								: ( $pantry_expanded 
									? 'huge' 
									: 'big' 
									)
								),
		),
		'content-excerpt',
		$pantry_template_args
	) );

	// Title and post meta
	$pantry_show_title = get_the_title() != '';
	$pantry_show_meta  = count( $pantry_components ) > 0 && ! in_array( $pantry_hover, array( 'border', 'pull', 'slide', 'fade', 'info' ) );

	if ( $pantry_show_title ) {
		?>
		<div class="post_header entry-header">
			<?php
			// Post title
			if ( apply_filters( 'pantry_filter_show_blog_title', true, 'excerpt' ) ) {
				do_action( 'pantry_action_before_post_title' );
				if ( empty( $pantry_template_args['no_links'] ) ) {
					the_title( sprintf( '<h3 class="post_title entry-title"><a href="%s" rel="bookmark">', esc_url( get_permalink() ) ), '</a></h3>' );
				} else {
					the_title( '<h3 class="post_title entry-title">', '</h3>' );
				}
				do_action( 'pantry_action_after_post_title' );
			}
			?>
		</div><!-- .post_header -->
		<?php
	}

	// Post content
	if ( apply_filters( 'pantry_filter_show_blog_excerpt', empty( $pantry_template_args['hide_excerpt'] ) && pantry_get_theme_option( 'excerpt_length' ) > 0, 'excerpt' ) ) {
		?>
		<div class="post_content entry-content">
			<?php

			// Post meta
			if ( apply_filters( 'pantry_filter_show_blog_meta', $pantry_show_meta, $pantry_components, 'excerpt' ) ) {
				if ( count( $pantry_components ) > 0 ) {
					do_action( 'pantry_action_before_post_meta' );
					pantry_show_post_meta(
						apply_filters(
							'pantry_filter_post_meta_args', array(
								'components' => join( ',', $pantry_components ),
								'seo'        => false,
								'echo'       => true,
							), 'excerpt', 1
						)
					);
					do_action( 'pantry_action_after_post_meta' );
				}
			}

			if ( pantry_get_theme_option( 'blog_content' ) == 'fullpost' ) {
				// Post content area
				?>
				<div class="post_content_inner">
					<?php
					do_action( 'pantry_action_before_full_post_content' );
					the_content( '' );
					do_action( 'pantry_action_after_full_post_content' );
					?>
				</div>
				<?php
				// Inner pages
				wp_link_pages(
					array(
						'before'      => '<div class="page_links"><span class="page_links_title">' . esc_html__( 'Pages:', 'pantry' ) . '</span>',
						'after'       => '</div>',
						'link_before' => '<span>',
						'link_after'  => '</span>',
						'pagelink'    => '<span class="screen-reader-text">' . esc_html__( 'Page', 'pantry' ) . ' </span>%',
						'separator'   => '<span class="screen-reader-text">, </span>',
					)
				);
			} else {
				// Post content area
				pantry_show_post_content( $pantry_template_args, '<div class="post_content_inner">', '</div>' );
			}

			// More button
			if ( apply_filters( 'pantry_filter_show_blog_readmore',  ! isset( $pantry_template_args['more_button'] ) || ! empty( $pantry_template_args['more_button'] ), 'excerpt' ) ) {
				if ( empty( $pantry_template_args['no_links'] ) ) {
					do_action( 'pantry_action_before_post_readmore' );
					if ( pantry_get_theme_option( 'blog_content' ) != 'fullpost' ) {
						pantry_show_post_more_link( $pantry_template_args, '<p>', '</p>' );
					} else {
						pantry_show_post_comments_link( $pantry_template_args, '<p>', '</p>' );
					}
					do_action( 'pantry_action_after_post_readmore' );
				}
			}

			?>
		</div><!-- .entry-content -->
		<?php
	}
	?>
</article>
<?php

if ( is_array( $pantry_template_args ) ) {
	if ( ! empty( $pantry_template_args['slider'] ) || $pantry_columns > 1 ) {
		?>
		</div>
		<?php
	}
}
