<?php
/**
 * The custom template to display the content
 *
 * Used for index/archive/search.
 *
 * @package PANTRY
 * @since PANTRY 1.0.50
 */

$pantry_template_args = get_query_var( 'pantry_template_args' );
if ( is_array( $pantry_template_args ) ) {
	$pantry_columns    = empty( $pantry_template_args['columns'] ) ? 2 : max( 1, $pantry_template_args['columns'] );
	$pantry_blog_style = array( $pantry_template_args['type'], $pantry_columns );
} else {
	$pantry_template_args = array();
	$pantry_blog_style = explode( '_', pantry_get_theme_option( 'blog_style' ) );
	$pantry_columns    = empty( $pantry_blog_style[1] ) ? 2 : max( 1, $pantry_blog_style[1] );
}
$pantry_blog_id       = pantry_get_custom_blog_id( join( '_', $pantry_blog_style ) );
$pantry_blog_style[0] = str_replace( 'blog-custom-', '', $pantry_blog_style[0] );
$pantry_expanded      = ! pantry_sidebar_present() && pantry_get_theme_option( 'expand_content' ) == 'expand';
$pantry_components    = ! empty( $pantry_template_args['meta_parts'] )
							? ( is_array( $pantry_template_args['meta_parts'] )
								? join( ',', $pantry_template_args['meta_parts'] )
								: $pantry_template_args['meta_parts']
								)
							: pantry_array_get_keys_by_value( pantry_get_theme_option( 'meta_parts' ) );
$pantry_post_format   = get_post_format();
$pantry_post_format   = empty( $pantry_post_format ) ? 'standard' : str_replace( 'post-format-', '', $pantry_post_format );

$pantry_blog_meta     = pantry_get_custom_layout_meta( $pantry_blog_id );
$pantry_custom_style  = ! empty( $pantry_blog_meta['scripts_required'] ) ? $pantry_blog_meta['scripts_required'] : 'none';

if ( ! empty( $pantry_template_args['slider'] ) || $pantry_columns > 1 || ! pantry_is_off( $pantry_custom_style ) ) {
	?><div class="
		<?php
		if ( ! empty( $pantry_template_args['slider'] ) ) {
			echo 'slider-slide swiper-slide';
		} else {
			echo esc_attr( ( pantry_is_off( $pantry_custom_style ) ? 'column' : sprintf( '%1$s_item %1$s_item', $pantry_custom_style ) ) . "-1_{$pantry_columns}" );
		}
		?>
	">
	<?php
}
?>
<article id="post-<?php the_ID(); ?>" data-post-id="<?php the_ID(); ?>"
	<?php
	post_class(
			'post_item post_item_container post_format_' . esc_attr( $pantry_post_format )
					. ' post_layout_custom post_layout_custom_' . esc_attr( $pantry_columns )
					. ' post_layout_' . esc_attr( $pantry_blog_style[0] )
					. ' post_layout_' . esc_attr( $pantry_blog_style[0] ) . '_' . esc_attr( $pantry_columns )
					. ( ! pantry_is_off( $pantry_custom_style )
						? ' post_layout_' . esc_attr( $pantry_custom_style )
							. ' post_layout_' . esc_attr( $pantry_custom_style ) . '_' . esc_attr( $pantry_columns )
						: ''
						)
		);
	pantry_add_blog_animation( $pantry_template_args );
	?>
>
	<?php
	// Sticky label
	if ( is_sticky() && ! is_paged() ) {
		?>
		<span class="post_label label_sticky"></span>
		<?php
	}
	// Custom layout
	do_action( 'pantry_action_show_layout', $pantry_blog_id, get_the_ID() );
	?>
</article><?php
if ( ! empty( $pantry_template_args['slider'] ) || $pantry_columns > 1 || ! pantry_is_off( $pantry_custom_style ) ) {
	?></div><?php
	// Need opening PHP-tag above just after </div>, because <div> is a inline-block element (used as column)!
}
