/* Blog layout: Masonry
------------------------- */
body[class*="blog_style_classic-masonry"] .posts_container {
  margin-bottom: calc(-1 * (var(--theme-var-grid_gap) + 15px));
}

.masonry_wrap {
  position: relative;
  margin-right: calc( -1 * var(--theme-var-grid_gap ) );
}

.masonry_wrap .masonry_item {
  position: relative;
  display: inline-block;
  vertical-align: top;
  padding: 0 var(--theme-var-grid_gap) var(--theme-var-grid_gap) 0;
  margin-bottom: 0;
  width: 50%;
  border-width: 0;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
}
.masonry_wrap .masonry_item .post_layout_classic-masonry {
  padding-bottom: 0;
}

.masonry_wrap.no_margin {
  margin-right: 0;
}

.masonry_wrap.no_margin .masonry_item {
  padding: 0;
}

.masonry_wrap .masonry_item-1_1 {
  width: 100%;
}

.masonry_wrap .masonry_item-1_3 {
  width: 33.3333%;
}

.masonry_wrap .masonry_item-1_4 {
  width: 25%;
}

.masonry_item .post_title {
  margin: 0;
  font-size: 24px;
  line-height: 1.15em;
}

.post_layout_classic-masonry_1 .post_title,
.post_layout_classic-masonry_2 .post_title {
  margin: 0;
  font-size: 35px;
  line-height: 1.15em;
}

.sidebar_show .post_layout_classic-masonry_2 .post_title {
  margin: 0;
  font-size: 28px;
  line-height: 1.15em;
}

.post_layout_classic-masonry_3 .post_title {
  margin: 0;
  font-size: 28px;
  line-height: 1.19em;
}

.masonry_wrap .masonry_item {
  /* audio */
  /* video */
}
.masonry_wrap .masonry_item .format-audio .post_featured .post_audio_title {
  font-size: 24px;
  line-height: 1.3em;
  font-weight: 500;
  margin-top: 0.4em;
  margin-bottom: 0.5em;
}
.masonry_wrap .masonry_item .format-audio .post_featured .post_audio_author {
  font-size: 13px;
}
.masonry_wrap .masonry_item .post_info_audio {
  margin-top: 5px;
}
.masonry_wrap .masonry_item div.mejs-controls div.mejs-button > button {
  border: none;
}
.masonry_wrap .masonry_item div.mejs-controls div.mejs-button.mejs-playpause-button > button {
  background-color: var(--theme-color-bg_color) !important;
}
.masonry_wrap .masonry_item div.mejs-controls div.mejs-button.mejs-volume-button {
  width: 30px;
}
.masonry_wrap .masonry_item div.mejs-controls div.mejs-button.mejs-volume-button > button {
  width: 30px;
  height: 40px;
  line-height: 42px;
}
.masonry_wrap .masonry_item div.mejs-controls .mejs-horizontal-volume-slider {
  margin-left: 5px;
}
.masonry_wrap .masonry_item div.mejs-controls .mejs-time.mejs-duration-container {
  margin-right: 5px;
}
.masonry_wrap .masonry_item div.mejs-controls .mejs-time.mejs-currenttime-container {
  margin-left: 10px;
}
.masonry_wrap .masonry_item div.mejs-controls .mejs-time-rail {
  margin: 0 12px;
}
.masonry_wrap .masonry_item .format-audio .post_featured.without_thumb .post_audio:not(.with_iframe),
.masonry_wrap .masonry_item .single-format-audio .post_featured.without_thumb .post_audio:not(.with_iframe),
.masonry_wrap .masonry_item .sc_layouts_blog_item_featured .post_featured.without_thumb .post_audio:not(.with_iframe) {
  padding: 30px;
}
.masonry_wrap .masonry_item .trx_addons_video_player.with_cover .video_hover,
.masonry_wrap .masonry_item .post_featured.with_thumb .post_video_hover {
  width: 65px;
  height: 65px;
  line-height: 65px;
  margin: -32px 0 0 -32px;
  font-size: 17px;
  letter-spacing: -4px;
}
.masonry_wrap .masonry_item .post_featured {
  margin-bottom: 1.85em;
}
.masonry_wrap .masonry_item .post_layout_portfolio .post_featured {
  margin-bottom: 0;
}
.masonry_wrap .masonry_item .post_layout_classic-masonry_4 .post_featured {
  margin-bottom: 1em;
}
.masonry_wrap .masonry_item .swiper-pagination-bullets {
  display: none;
}
.masonry_wrap .masonry_item .slider_container.slider_controls_side .slider_controls_wrap > a, .masonry_wrap .masonry_item .slider_outer_controls_side .slider_controls_wrap > a {
  opacity: 1;
  margin-left: 30px;
  margin-right: 30px;
}
.masonry_wrap .masonry_item .slider_container.slider_controls_side .slider_controls_wrap > a,
.masonry_wrap .masonry_item .slider_outer_controls_side .slider_controls_wrap > a {
  width: 34px;
  height: 34px;
  line-height: 30px;
}
.masonry_wrap .masonry_item .slider_container.slider_controls_side .slider_controls_wrap > a:before,
.masonry_wrap .masonry_item .slider_outer_controls_side .slider_controls_wrap > a:before {
  font-size: 13px;
}
.masonry_wrap .masonry_item .swiper-button-next, .masonry_wrap .masonry_item .swiper-button-prev {
  margin-top: -17px !important;
}
.masonry_wrap .masonry_item .post_header .post_meta_item.post_categories {
  font-size: 12px;
  font-weight: 700;
  text-transform: uppercase;
  letter-spacing: 0.7px;
  color: var(--theme-color-text_dark);
}
.masonry_wrap .masonry_item .post_header .post_meta_item.post_categories a {
  color: var(--theme-color-text_dark);
}
.masonry_wrap .masonry_item .post_header .post_meta_item.post_categories a:hover {
  color: var(--theme-color-text_link);
}
.masonry_wrap .masonry_item .post_header {
  padding: 0 0 14px;
}
.masonry_wrap .masonry_item .post_header .post_meta {
  margin: 0 0 12px;
}
.masonry_wrap .masonry_item .post_layout_classic-masonry_3 .post_header {
  padding: 0 0 17px 50px;
}
.masonry_wrap .masonry_item .post_layout_classic-masonry_1 .post_header,
.masonry_wrap .masonry_item .post_layout_classic-masonry_2 .post_header {
  padding: 0 0 25px 50px;
}
.masonry_wrap .masonry_item .post_layout_classic-masonry_1 .post_header,
.masonry_wrap .masonry_item .post_layout_classic-masonry_2 .post_header,
.masonry_wrap .masonry_item .post_layout_classic-masonry_3 .post_header {
  position: relative;
}
.masonry_wrap .masonry_item .post_layout_classic-masonry_1 .post_header .post_meta,
.masonry_wrap .masonry_item .post_layout_classic-masonry_2 .post_header .post_meta,
.masonry_wrap .masonry_item .post_layout_classic-masonry_3 .post_header .post_meta {
  margin: 0 0 12px;
}
.masonry_wrap .masonry_item .post_layout_classic-masonry_1 .post_header:before,
.masonry_wrap .masonry_item .post_layout_classic-masonry_2 .post_header:before,
.masonry_wrap .masonry_item .post_layout_classic-masonry_3 .post_header:before {
  position: absolute;
  left: 0;
  top: 9px;
  width: 35px;
  height: 2px;
  content: "";
  display: block;
  background-color: var(--theme-color-text_dark);
}

/*# sourceMappingURL=masonry.css.map */
