<?php
/**
 * The template to display the copyright info in the footer
 *
 * @package PANTRY
 * @since PANTRY 1.0.10
 */

// Copyright area
?> 
<div class="footer_copyright_wrap
<?php
$pantry_copyright_scheme = pantry_get_theme_option( 'copyright_scheme' );
if ( ! empty( $pantry_copyright_scheme ) && ! pantry_is_inherit( $pantry_copyright_scheme  ) ) {
	echo ' scheme_' . esc_attr( $pantry_copyright_scheme );
}
?>
				">
	<div class="footer_copyright_inner">
		<div class="content_wrap">
			<div class="copyright_text">
			<?php
				$pantry_copyright = pantry_get_theme_option( 'copyright' );
			if ( ! empty( $pantry_copyright ) ) {
				// Replace {{Y}} or {Y} with the current year
				$pantry_copyright = str_replace( array( '{{Y}}', '{Y}' ), date( 'Y' ), $pantry_copyright );
				// Replace {{...}} and ((...)) on the <i>...</i> and <b>...</b>
				$pantry_copyright = pantry_prepare_macros( $pantry_copyright );
				// Display copyright
				echo wp_kses( nl2br( $pantry_copyright ), 'pantry_kses_content' );
			}
			?>
			</div>
		</div>
	</div>
</div>
