<?php
/**
 * The template to display the site logo in the footer
 *
 * @package PANTRY
 * @since PANTRY 1.0.10
 */

// Logo
if ( pantry_is_on( pantry_get_theme_option( 'logo_in_footer' ) ) ) {
	$pantry_logo_image = pantry_get_logo_image( 'footer' );
	$pantry_logo_text  = get_bloginfo( 'name' );
	if ( ! empty( $pantry_logo_image['logo'] ) || ! empty( $pantry_logo_text ) ) {
		?>
		<div class="footer_logo_wrap">
			<div class="footer_logo_inner">
				<?php
				if ( ! empty( $pantry_logo_image['logo'] ) ) {
					$pantry_attr = pantry_getimagesize( $pantry_logo_image['logo'] );
					echo '<a href="' . esc_url( home_url( '/' ) ) . '">'
							. '<img src="' . esc_url( $pantry_logo_image['logo'] ) . '"'
								. ( ! empty( $pantry_logo_image['logo_retina'] ) ? ' srcset="' . esc_url( $pantry_logo_image['logo_retina'] ) . ' 2x"' : '' )
								. ' class="logo_footer_image"'
								. ' alt="' . esc_attr__( 'Site logo', 'pantry' ) . '"'
								. ( ! empty( $pantry_attr[3] ) ? ' ' . wp_kses_data( $pantry_attr[3] ) : '' )
							. '>'
						. '</a>';
				} elseif ( ! empty( $pantry_logo_text ) ) {
					echo '<h1 class="logo_footer_text">'
							. '<a href="' . esc_url( home_url( '/' ) ) . '">'
								. esc_html( $pantry_logo_text )
							. '</a>'
						. '</h1>';
				}
				?>
			</div>
		</div>
		<?php
	}
}
