<?php
/**
 * The template to display the page title and breadcrumbs
 *
 * @package PANTRY
 * @since PANTRY 1.0
 */

// Page (category, tag, archive, author) title

if ( pantry_need_page_title() ) {
	pantry_sc_layouts_showed( 'title', true );
	pantry_sc_layouts_showed( 'postmeta', true );
	?>
	<div class="top_panel_title sc_layouts_row sc_layouts_row_type_normal">
		<div class="content_wrap">
			<div class="sc_layouts_column sc_layouts_column_align_center">
				<div class="sc_layouts_item">
					<div class="sc_layouts_title sc_align_center">
						<?php
						// Post meta on the single post
						if ( is_single() ) {
							?>
							<div class="sc_layouts_title_meta">
							<?php
								pantry_show_post_meta(
									apply_filters(
										'pantry_filter_post_meta_args', array(
											'components' => join( ',', pantry_array_get_keys_by_value( pantry_get_theme_option( 'meta_parts' ) ) ),
											'counters'   => join( ',', pantry_array_get_keys_by_value( pantry_get_theme_option( 'counters' ) ) ),
											'seo'        => pantry_is_on( pantry_get_theme_option( 'seo_snippets' ) ),
										), 'header', 1
									)
								);
							?>
							</div>
							<?php
						}

						// Blog/Post title
						?>
						<div class="sc_layouts_title_title">
							<?php
							$pantry_blog_title           = pantry_get_blog_title();
							$pantry_blog_title_text      = '';
							$pantry_blog_title_class     = '';
							$pantry_blog_title_link      = '';
							$pantry_blog_title_link_text = '';
							if ( is_array( $pantry_blog_title ) ) {
								$pantry_blog_title_text      = $pantry_blog_title['text'];
								$pantry_blog_title_class     = ! empty( $pantry_blog_title['class'] ) ? ' ' . $pantry_blog_title['class'] : '';
								$pantry_blog_title_link      = ! empty( $pantry_blog_title['link'] ) ? $pantry_blog_title['link'] : '';
								$pantry_blog_title_link_text = ! empty( $pantry_blog_title['link_text'] ) ? $pantry_blog_title['link_text'] : '';
							} else {
								$pantry_blog_title_text = $pantry_blog_title;
							}
							?>
							<h1 itemprop="headline" class="sc_layouts_title_caption<?php echo esc_attr( $pantry_blog_title_class ); ?>">
								<?php
								$pantry_top_icon = pantry_get_term_image_small();
								if ( ! empty( $pantry_top_icon ) ) {
									$pantry_attr = pantry_getimagesize( $pantry_top_icon );
									?>
									<img src="<?php echo esc_url( $pantry_top_icon ); ?>" alt="<?php esc_attr_e( 'Site icon', 'pantry' ); ?>"
										<?php
										if ( ! empty( $pantry_attr[3] ) ) {
											pantry_show_layout( $pantry_attr[3] );
										}
										?>
									>
									<?php
								}
								echo wp_kses_data( $pantry_blog_title_text );
								?>
							</h1>
							<?php
							if ( ! empty( $pantry_blog_title_link ) && ! empty( $pantry_blog_title_link_text ) ) {
								?>
								<a href="<?php echo esc_url( $pantry_blog_title_link ); ?>" class="theme_button theme_button_small sc_layouts_title_link"><?php echo esc_html( $pantry_blog_title_link_text ); ?></a>
								<?php
							}

							// Category/Tag description
							if ( ! is_paged() && ( is_category() || is_tag() || is_tax() ) ) {
								the_archive_description( '<div class="sc_layouts_title_description">', '</div>' );
							}

							?>
						</div>
						<?php

						// Breadcrumbs
						ob_start();
						do_action( 'pantry_action_breadcrumbs' );
						$pantry_breadcrumbs = ob_get_contents();
						ob_end_clean();
						pantry_show_layout( $pantry_breadcrumbs, '<div class="sc_layouts_title_breadcrumbs">', '</div>' );
						?>
					</div>
				</div>
			</div>
		</div>
	</div>
	<?php
}
