@import "../../../../css/_mixins.scss";
@import "../../../../css/_theme-vars.scss";
@import "../../css/_skin-vars.scss";


@media #{$media_xl} {
	.post_layout_band .post_title {
		font-size: 24px;
	}
	.post_layout_band .post_content_wrap .post_category {
		margin-bottom: 0.7em;
	}
}

@media #{$media_lg} {
	/* Blog layout: Band */
	.post_layout_band {
		.post_header .post_price {
			@include font(1.5em, 1.5em);
		}
		.post_content_wrap {
			padding: 2em;
		}
		.post_title {
			font-size: 22px;
		}
		.post_header + .post_content {
			margin-top: 0.7em;
		}
		.post_content + .post_meta {
			margin-top: 17px;
		}
		.post_content + .post_meta:before {
			margin-bottom: 16px;
		}
		.post_content_wrap .post_category {
			margin-bottom: 0.6em;
		}
	}
}

@media #{$media_md} {
	/* Blog layout: Band */
}


@media #{$media_sm} {
	/* Blog layout: Band */
	.post_layout_band {
		@include flex-direction(column);
		.post_featured {
			@include flex-basis(100%);
		}
		.post_featured + .post_content_wrap {
			@include flex-basis(100%);
		}
		.post_header .post_price {
			position:static;
			right: auto;
			top: auto;
			margin-top:0.3em;
		}
	}
	.post_layout_band.post_format_audio .post_featured {
		width: 100%;
		&.without_thumb .post_audio:not(.with_iframe) {
			padding: 2.5em 2.1em 0;
		}
	}
	.post_layout_band.post_format_quote .post_content_wrap {
		padding: 36px 38px !important;
	}
}

@media #{$media_sm_phone} {
	.post_layout_band {
		@include flex-direction(row);
		.post_featured {
			@include flex-basis(48%);
		}
		.post_featured + .post_content_wrap {
			@include flex-basis(52%);
		}
		.post_header .post_price {
			position:static;
			right: auto;
			top: auto;
			margin-top:0.3em;
		}
	}
}


@media #{$media_xs} {
	/* Blog layout: Band */
	.post_layout_band .post_content_wrap {
		padding: 1.5em;
		.post_content_inner {
			line-height: 1.5em;
		}
	}
	.post_layout_band .post_title {
		font-size: 20px;
		line-height: 24px;
	}
	.post_layout_band .post_content_wrap .post_category {
		margin-bottom: 0.4em;
	}
	.post_layout_band.post_format_audio .post_featured {
		&.without_thumb .post_audio:not(.with_iframe) {
			padding: 2.5em 1.5em 0;
		}
	}
	.post_layout_band.post_format_quote .post_content_wrap {
		padding: 23px 24px !important;
	}
}