<?php
/**
 * The template to display default site footer
 *
 * @package PANTRY
 * @since PANTRY 1.0.10
 */

$pantry_footer_id = pantry_get_custom_footer_id();
$pantry_footer_meta = get_post_meta( $pantry_footer_id, 'trx_addons_options', true );
if ( ! empty( $pantry_footer_meta['margin'] ) ) {
	pantry_add_inline_css( sprintf( '.page_content_wrap{padding-bottom:%s}', esc_attr( pantry_prepare_css_value( $pantry_footer_meta['margin'] ) ) ) );
}
?>
<footer class="footer_wrap footer_custom footer_custom_<?php echo esc_attr( $pantry_footer_id ); ?> footer_custom_<?php echo esc_attr( sanitize_title( get_the_title( $pantry_footer_id ) ) ); ?>
						<?php
						$pantry_footer_scheme = pantry_get_theme_option( 'footer_scheme' );
						if ( ! empty( $pantry_footer_scheme ) && ! pantry_is_inherit( $pantry_footer_scheme  ) ) {
							echo ' scheme_' . esc_attr( $pantry_footer_scheme );
						}
						?>
						">
	<?php
	// Custom footer's layout
	do_action( 'pantry_action_show_layout', $pantry_footer_id );
	?>
</footer><!-- /.footer_wrap -->
