@import "../../../../css/_mixins.scss";
@import "../../../../css/_theme-vars.scss";
@import "../../css/_skin-vars.scss";


.single_style_style-3 .page_content_wrap {
	padding-top: 0;
}
.single_style_style-3 .page_content_wrap > .content_wrap {
	padding-top: 3em;
}
.post_header_wrap_style_style-3 {
	position: relative;
}
.post_header_wrap_style_style-3.post_header_wrap_in_header {
	margin-top: 4em;
}
.post_header_wrap_style_style-3.post_header_wrap_in_header.with_featured_image {
	margin-top: 0;
}
.post_header_wrap_style_style-3 .post_featured {
	margin-top: 0;
	margin-bottom: 0;
}
.post_header_wrap_style_style-3 .post_featured.with_audio.without_thumb {
	margin: 0 var(--theme-var-grid_gap);
}
.post_header_wrap_style_style-3 .post_featured.with_gallery {
	.slider_container .slider_pagination_wrap .swiper-pagination-bullet {
		@include box(6px, 6px);
		opacity: 1;
		border-color:  var(--theme-color-inverse_link);
		background-color: transparent;
		&.swiper-pagination-bullet-active {
			border-color:  var(--theme-color-text_link);
			background-color: var(--theme-color-text_link);
		}
	}
}
.post_header_wrap_style_style-3 .post_featured.post_featured_bg,
.post_header_wrap_style_style-3 .post_featured.sc_parallax_wrap {
	height: 36.7rem;
}
.post_header_wrap_style_style-3 .post_featured.post_featured_bg {
	background-position: center;
}
.post_header_wrap_style_style-3 .post_featured.sc_parallax_wrap {
	@include flex;
	@include flex-align-items( center );
	img {
		position: relative;
	}
	&.sc_parallax_direction_down img {
		top: -15%;
	}
	&.sc_parallax_direction_up {
		top: 15%;
	}
}
.post_header_wrap_style_style-3 .post_featured.post_featured_bg:before {
	display:none;
}
.post_header_wrap_style_style-3 .post_featured img {
	max-width: none;
	width: 100%;
}
.post_header_wrap_style_style-3 .post_header {
	display: block;
	text-align: center;
	margin-top: 0;
	padding: 0 30px;
	.content_wrap {
		background-color: var(--theme-color-bg_color);
		width: 100%;
		max-width: 1060px;
		padding: 55px;
		@include box-sizing(border-box);
		z-index: 9;
	}
}
.post_header_wrap_style_style-3 {
	.post_featured  + .post_header_single {
		margin-top: -120px;
	}
	.post_featured.with_audio.without_thumb  + .post_header_single {
		margin-top: 0;
	}
}
.post_header_wrap_style_style-3 .post_header .post_title,
.post_header_wrap_style_style-3 .post_header .post_subtitle {
	margin: 0 auto;
	max-width: 85%;
}
.post_header_wrap_style_style-3 .post_header .post_title {
	line-height: 1em;
}
.post_header_wrap_style_style-3 .post_header .post_subtitle {
	@include font(1.2857em, 1.4em, normal);
	margin-top: 1em;
}
.post_header_wrap_style_style-3 .post_header .post_meta_categories {
    margin-top: 0;
	margin-bottom: 24px;
	text-transform: uppercase;
	letter-spacing: 0;
	@include font( inherit, inherit, 500);
	@include flex-justify-content(center);
	.post_meta_item:after {
		position: relative;
		top: 2px;
	}
}
.post_header_wrap_style_style-3 .post_header .post_meta_other {
	margin-top: 2em;
	@include flex-justify-content(center);
}
.post_header_wrap_style_style-3 .post_header .post_meta_other .post_meta_item {
	white-space: nowrap;
	line-height: 1.75em;
}
.post_header_wrap_style_style-3 .post_header .post_meta_other .post_share {
	display: inline-block;
	vertical-align: top;
}
.post_header_wrap_style_style-3 .post_header .post_meta_other .post_share .social_item {
	margin: 0 10px 0 0;
	font-size: 1.15em;
}
.post_header_wrap_style_style-3 .post_header .post_meta_other .post_meta_item:after,
.post_header_wrap_style_style-3 .post_header .post_meta_other .vc_inline-link:after {
	margin: 0 0.5em 0 0.74em;
}
.post_header_wrap_style_style-3 .post_author_name {
	color: var(--theme-color-text_dark);
	@include transition-property(color);
}
.post_header_wrap_style_style-3 a:hover .post_author_name,
.post_header_wrap_style_style-3 a:focus .post_author_name {
	color: var(--theme-color-text_hover);
}
.post_header_wrap_style_style-3 .post_header .post_meta_other .post_author_avatar {
	margin-right: 0.85em;
	margin-top: -3px;
	> img {
		width: 32px;
		height: 32px;
		line-height: 32px;
		text-align: center;
	}
}
.single_style_style-3 {
	&.single-format-audio {
		.post_header_wrap_in_header .post_featured.with_thumb {
			.post_audio {
				width: 100%;
				max-width: 1060px;
				left: 50%;
				right: auto;
				bottom: 140px;
				transform: translateX(-50%);
			}
			&:after {
				display: none !important;
			}
		}
	}
	&.single-format-video {
		.post_featured + .post_header_single {
			margin-top: 0;
		}
	}
	&.single-format-gallery {
		.post_featured + .post_header_single {
			margin-top: 0;
		}
	}
}
.single_style_style-3.single-format-audio {
	.post_header_wrap_in_header.with_featured_image {
		.post_audio {
			.post_info_audio {
				text-align: left;
				max-width: 100%;
				padding: 30px;
				margin-bottom: 20px;
				background-color: var(--theme-color-alter_bg_color);
				box-sizing: border-box;
				.post_audio_author,
				.post_audio_description,
				.post_audio_title {
					overflow: hidden;
					text-overflow: ellipsis;
					display: -webkit-box;
					-webkit-box-orient: vertical;
					display: -moz-box;
					-moz-box-orient: vertical;
					box-orient: vertical;
					max-width: 65%;
					color: var(--theme-color-alter_dark);
				}
				.post_audio_author {
					-webkit-line-clamp: 1;
					-moz-line-clamp: 1;
					line-clamp: 1;
				}
				.post_audio_description {
					-webkit-line-clamp: 3;
					-moz-line-clamp: 3;
					line-clamp: 3;
				}
				.post_audio_title {
					-webkit-line-clamp: 2;
					-moz-line-clamp: 2;
					line-clamp: 2;
				}
				.post_audio_description {
					margin-bottom: 0;
				}
			}
		}
	}
	.post_header_wrap_in_header {
		.post_featured.without_thumb {
			.post_audio {
				max-width: 70%;
				margin: 0 auto;
				.post_info_audio {
					max-width: 65%;
				}
			}
		}
	}
}
.single_style_style-3 .post_featured.with_video.without_thumb .post_info_video {
	position: relative;
	padding: 1.5em;
	background-color: rgba(0,0,0,0.7);
}