<?php
/**
 * Display banner
 */

defined( 'ABSPATH' ) || exit;
?>

<div class="wpcfr-banner">
	<div class="wpcfr-banner-holder">
		<span class="dashicons dashicons-no close-banner" title="<?php _e( 'Close', 'wpcf7-redirect' ); ?>"></span>
		<a href="https://redirection-for-contact-form7.com/" target="_blank">
			<img src="<?php echo wpcf7r_get_redirect_plugin_url(); ?>/assets/images/banner.png" alt="Get pro version" />
		</a>
	</div>
</div>
