.sp-eab-pro-blocks-placeholder {
    max-width: 846px;
    width: 100%;
    height: 250px;
    margin: 0 auto;
    padding: 32px 32px 0 32px;
    background: #FFF3F3;
    border: 1px solid #FEAD96;
    border-radius: 11px;
    box-sizing: border-box;
    position: relative;

    .sp-eab-pro-block-placeholder-remove {
        background: none;
        border: none;
        outline: none;
        box-shadow: none;
        cursor: pointer;
        position: absolute;
        right: 16px;
        top: 18px;
        color: #757575;
        font-size: 18px;

        .eab-pro-block-close-icon {
            position: relative;
            width: 20px;
            height: 20px;
            cursor: pointer;
        }

        .eab-pro-block-close-icon::before,
        .eab-pro-block-close-icon::after {
            content: "";
            position: absolute;
            top: 50%;
            left: 50%;
            width: 14px;
            height: 2px;
            background: #646970;
            transform-origin: center;
        }

        .eab-pro-block-close-icon::before {
            transform: translate(-50%, -50%) rotate(45deg);
        }

        .eab-pro-block-close-icon::after {
            transform: translate(-50%, -50%) rotate(-45deg);
        }
    }

    .sp-eab-pro-blocks-placeholder-left {
        max-width: 410px;
    }

    .sp-eab-pro-blocks-placeholder-right {
        max-width: 320px;
        margin-bottom: -3px;

        img {
            width: 100%;
            height: 100%;
        }
    }
}

.sp-eab-pro-block-placeholder-title {
    color: var(--eab-primary-text-color);
    font-size: 20px;
    font-weight: 700;
    line-height: 1;
}

.sp-eab-pro-block-placeholder-desc {
    color: var(--eab-primary-text-color);
    font-size: 16px;
    font-weight: 400;
    line-height: 160%;
    margin-top: 12px;
}

.sp-eab-pro-plan-btn-wrapper {
    gap: 14px;
    margin-top: 30px;

    a {
        text-decoration: none !important;
        padding: 11px 24px;
        border-radius: 6px;
        font-size: 16px;
        font-weight: 600;
        color: #FFFFFF;
        outline: none;
        transition: all 0.4s ease-in-out;

        &.sp-eab-pro-plan-demo-btn {
            background-color: var(--eab-primary-color);
            color: #FFFFFF;

            &:hover {
                color: #FFFFFF;
                background-color: var(--eab-primary-color-hover);
            }
        }

        &.sp-eab-pro-plan-upgrade-btn {
            background-color: #01B150;
            color: #FFFFFF;

            &:hover {
                color: #FFFFFF;
                background-color: #00a247;
            }
        }
    }
}