/* Blog layout: Band
------------------------- */

@import "../../../../css/_mixins.scss";
@import "../../../../css/_theme-vars.scss";
@import "../../css/_skin-vars.scss";

.post_layout_band {
	position:relative;
	margin-bottom:0;
}
.post_layout_band {
	@include flex;
	@include flex-direction(row);
	@include flex-wrap(nowrap);
	@include flex-align-items(stretch);
}
.post_layout_band + .post_layout_band {
	margin-top: 30px;
}
.post_layout_band {
	.post_featured {
		@include flex-basis(49%);
		@include flex-shrink(0);
		margin-bottom: 0;
		&.with_video.with_thumb:after {
			display: none;
		}
	}
	&.post_format_audio {
		.post_featured {
			align-self: center;
			.mask {
				display: none;
			}
			&.without_thumb .post_audio:not(.with_iframe) {
				padding: 2.5em 2em;
			}
		}
	}
	&.post_format_quote {
		.post_content_wrap {
			padding: 36px 38px !important;
			.post_header + .post_content {
				margin-top: 1.4em;
			}
			.post_content_inner {
				blockquote {
					+ p {
						margin-top: 1.3em;
					}
				}
				p {
					&:last-child {
						margin-bottom: 0;
					}
				}
			}
		}
	}
}
.post_layout_band .post_content_wrap {
	@include border-box;
	padding: 2.1em 2.2em 1.9em;
	@include flex;
	@include flex-direction(column);
	@include flex-justify-content(center);

	.post_content_inner {
		line-height: 1.6em;
	}
	.post_category {
		margin-bottom: 1.05em;
		.post_meta {
			margin: 0;
		}
	}
	.post_meta_item.post_categories a {
		@include border-radius(0);
		background-color: var(--theme-color-text_link2);
		color: var(--theme-color-inverse_link);
		text-transform: uppercase;
		padding: 5px 17px;
		@include box-sizing(border-box);
		font-size: 11px;
		line-height: 15px;
		font-weight: 700;
		letter-spacing: 0.7px;
		&:hover,
		&:focus {
			background-color: var(--theme-color-text_dark);
			color: var(--theme-color-inverse_hover);
		}
	}
	.post_meta_item.post_sponsored .post_sponsored_label {
		@include border-radius(0);
		background-color: var(--theme-color-text_link);
		color: var(--theme-color-inverse_link);
		text-transform: uppercase;
		padding: 5px 17px;
		@include box-sizing(border-box);
		font-size: 11px;
		line-height: 15px;
		font-weight: 700;
		letter-spacing: 0.7px;
		display: inline-block;
		margin-top: 2px;
		margin-bottom: 2px;
	}
	.post_meta_item.post_sponsored a.post_sponsored_label:hover {
		background-color: var(--theme-color-text_dark);
		color: var(--theme-color-inverse_hover);
	}
}
.post_layout_band .post_featured + .post_content_wrap {
	@include flex-basis(51%);
}
.post_layout_band.post_format_quote .post_content_wrap,
.post_layout_band.post_format_aside .post_content_inner {
	padding: 0;
	background-color: transparent;
	color: inherit;
}
.post_layout_band blockquote {
	margin: 0;
}
.post_layout_band .post_header {
	margin: 0;
	position:relative;
}
.post_layout_band .post_header .post_price {
	width: auto;
	@include abs-rt;
	@include font(2.5em, 1.5em);
}
.post_layout_band .post_title {
	margin: 0;
	font-size: 26px;
}
.post_layout_band .post_header + .post_content {
	margin-top:1em;
}
.post_layout_band .post_content + .post_meta {
	margin-top: 23px;
	padding: 0;
	position: relative;
	&:before {
		content: '';
		display: block;
		width: 60px;
		height: 1px;
		margin-bottom: 20px;
		background-color: var(--theme-color-text_dark);
	}
}
.post_item.post_layout_band {
	background-color: var(--theme-color-alter_bg_color);
}

.post_item.post_layout_band {
	&.sticky:not(.post_layout_custom) {
		border: none;
		padding: 0;
		.label_sticky {
			display:block;
			@include abs-rt(-12px, -12px);
			z-index: 9;
			@include box(0, 0);
			border: 12px solid transparent;
			border-top-color:var(--theme-color-text_link);
			@include rotate(225deg);
		}
	}
}