.single_style_style-1 .page_content_wrap {
  padding-top: 0;
}

.single_style_style-1 .post_header_single .content_wrap {
  padding-right: 50px;
  padding-left: 50px;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
}

.narrow_content.single_style_style-1 .post_header_single .content_wrap {
  padding-right: 90px;
  padding-left: 90px;
  width: 100%;
  max-width: var(--theme-var-content);
}
.narrow_content.single_style_style-1.single-format-audio .with_featured_image .post_featured.with_audio.with_thumb + .post_header_single .content_wrap {
  padding-right: 0;
  padding-left: 0;
}

.single_style_style-1 .page_content_wrap > .content_wrap {
  padding-top: 6.2em;
}

.post_header_wrap_style_style-1 {
  position: relative;
  margin-top: 6.2em;
  text-align: center;
}
.header_position_over .post_header_wrap_style_style-1 {
  margin-top: 0;
}

/* header over */
.header_position_over.single_style_style-1 .post_header_wrap_style_style-1 {
  text-align: left;
}
.header_position_over.single_style_style-1 .post_header_wrap_style_style-1 .post_featured.with_thumb:not(.with_video) + .post_header,
.header_position_over.single_style_style-1 .post_header_wrap_style_style-1 .post_featured.with_gallery + .post_header {
  -webkit-transform: translate(-50%, 0);
  -ms-transform: translate(-50%, 0);
  transform: translate(-50%, 0);
  bottom: 4.8em;
  top: auto;
  width: 100%;
}
.header_position_over.single_style_style-1 .page_content_wrap > .content_wrap {
  padding-top: 6.5em;
}
.header_position_over.single_style_style-1 .post_header_single .content_wrap {
  padding-right: 0;
  padding-left: 0;
}

.previous_post_content .post_header_wrap_style_style-1.post_header_wrap_in_header {
  margin-bottom: 4em;
}

.post_header_wrap_style_style-1.with_featured_image {
  margin-top: 0;
}

.post_header_wrap_style_style-1 .post_featured {
  margin-top: 0;
  margin-bottom: 0;
  z-index: 1 !important;
}
.post_header_wrap_style_style-1 .post_featured.with_video, .post_header_wrap_style_style-1 .post_featured.with_gallery {
  z-index: auto !important;
}

.post_header_wrap_style_style-1 .post_featured.with_gallery .slider_container .slider_pagination_wrap .swiper-pagination-bullet {
  width: 6px;
  height: 6px;
  opacity: 1;
  border-color: var(--theme-color-inverse_link);
  background-color: transparent;
}
.post_header_wrap_style_style-1 .post_featured.with_gallery .slider_container .slider_pagination_wrap .swiper-pagination-bullet.swiper-pagination-bullet-active {
  border-color: var(--theme-color-text_link);
  background-color: var(--theme-color-text_link);
}

.post_header_wrap_style_style-1 .post_featured.post_featured_bg,
.post_header_wrap_style_style-1 .post_featured.sc_parallax_wrap {
  height: 37.7rem;
}

.post_header_wrap_style_style-1 .post_featured.post_featured_bg {
  background-position: center;
}

.post_header_wrap_style_style-1 .post_featured.sc_parallax_wrap {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
}
.post_header_wrap_style_style-1 .post_featured.sc_parallax_wrap img {
  position: relative;
}
.post_header_wrap_style_style-1 .post_featured.sc_parallax_wrap.sc_parallax_direction_down img {
  top: -15%;
}
.post_header_wrap_style_style-1 .post_featured.sc_parallax_wrap.sc_parallax_direction_up {
  top: 15%;
}

.post_header_wrap_style_style-1 .post_featured.post_featured_bg:before {
  display: none;
}

.post_header_wrap_style_style-1 .post_featured img {
  max-width: none;
  width: 100%;
}

.post_header_wrap_style_style-1.with_featured_image:before {
  content: ' ';
  display: block;
  position: absolute;
  z-index: 3;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  pointer-events: none;
  background: rgba(0, 0, 0, 0.45);
}

.post_header_wrap_style_style-1 .post_author {
  color: var(--theme-color-text_dark);
}
.post_header_wrap_style_style-1 .post_author:hover, .post_header_wrap_style_style-1 .post_author:focus {
  color: var(--theme-color-text_hover);
}

.post_header_wrap_style_style-1.with_featured_image .post_header a,
.post_header_wrap_style_style-1.with_featured_image .post_header .post_title,
.post_header_wrap_style_style-1.with_featured_image .post_header .post_subtitle,
.post_header_wrap_style_style-1.with_featured_image .post_header .post_meta_item {
  color: #fff !important;
}

.post_header_wrap_style_style-1.with_featured_image .post_header .post_date,
.post_header_wrap_style_style-1.with_featured_image .post_header .post_meta_item,
.post_header_wrap_style_style-1.with_featured_image .post_header .post_meta_item a {
  color: #A5A6AA !important;
}

.post_header_wrap_style_style-1.with_featured_image .post_header .post_meta_item.post_author,
.post_header_wrap_style_style-1.with_featured_image .post_header .post_meta.post_meta_categories a {
  color: #fff !important;
}

.post_header_wrap_style_style-1.with_featured_image .post_header a,
.post_header_wrap_style_style-1.with_featured_image .post_header a.post_author .post_author_name {
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
}

.post_header_wrap_style_style-1.with_featured_image .post_header .post_subtitle,
.post_header_wrap_style_style-1.with_featured_image .post_header a:hover,
.post_header_wrap_style_style-1.with_featured_image .post_header a:focus,
.post_header_wrap_style_style-1.with_featured_image .post_header a.post_author:hover .post_author_name,
.post_header_wrap_style_style-1.with_featured_image .post_header a.post_author:focus .post_author_name {
  opacity: 1;
  color: #ffffff !important;
}

.post_header_wrap_style_style-1.with_featured_image .post_header .post_meta.post_meta_categories a:hover {
  color: #000 !important;
  background-color: #ffffff !important;
  opacity: 1;
}

.post_header_wrap_style_style-1.with_featured_image .post_header a.post_author:hover,
.post_header_wrap_style_style-1.with_featured_image .post_header a.post_author:focus {
  opacity: 1;
}

.post_header_wrap_style_style-1.with_featured_image .post_header .social_item {
  vertical-align: baseline;
}

.post_header_wrap_style_style-1 .post_featured .post_video_list {
  width: 100%;
}

.post_header_wrap_style_style-1 .post_featured.with_thumb .post_audio {
  bottom: 1em;
}
.post_header_wrap_style_style-1 .post_featured.with_thumb .post_audio .audio_info {
  display: none;
}

.post_header_wrap_style_style-1 .post_header {
  display: block;
}

.post_header_wrap_style_style-1 .post_featured.with_thumb + .post_header,
.post_header_wrap_style_style-1 .post_featured.with_gallery + .post_header {
  display: inline-block;
  position: absolute;
  z-index: 10;
  top: 50%;
  left: 50%;
  -webkit-transform: translate(-50%, -50%);
  -ms-transform: translate(-50%, -50%);
  transform: translate(-50%, -50%);
  box-sizing: border-box;
  margin-bottom: 0;
  margin-top: 0;
}

/* to do: until clarification
.single-format-audio .post_header_wrap_style_style-1 .post_featured.with_thumb + .post_header {
	margin-bottom: 4em;
}
*/
.single-format-video .post_header_wrap_style_style-1 .post_featured.with_video.with_thumb .post_video_hover {
  margin-top: -3em;
}
.single-format-video .post_header_wrap_style_style-1 .post_featured.with_video .post_info_video {
  display: none;
}
.single-format-video .post_header_wrap_style_style-1 .post_featured.with_video + .post_header {
  z-index: 2001;
}

.post_header_wrap_style_style-1 .post_featured.with_video + .post_header,
.post_header_wrap_style_style-1 .post_featured.with_video_list + .post_header {
  margin-top: 0;
}

.post_header_wrap_style_style-1 .post_featured.post_video_play + .post_header {
  display: none;
}

.post_header_wrap_style_style-1 .post_header .post_title {
  margin-top: 0;
  margin-bottom: 0;
  line-height: 1em;
}

.post_header_wrap_style_style-1 .post_header .post_subtitle {
  font-size: 1.2857em;
  line-height: 1.4em;
  font-weight: normal;
  margin-top: 1em;
}

.post_header_wrap_style_style-1 .post_header .post_meta_categories {
  margin-top: 0;
  margin-bottom: 24px;
  text-transform: uppercase;
  letter-spacing: 0;
  font-size: inherit;
  line-height: inherit;
  font-weight: 500;
}
.post_header_wrap_style_style-1 .post_header .post_meta_categories .post_meta_item:after {
  position: relative;
  top: 2px;
}

.post_header_wrap_style_style-1 .post_header .post_meta_other {
  margin-top: 1em;
}

.post_header_wrap_style_style-1 .post_header .post_meta_other .post_meta_item {
  white-space: nowrap;
}

.post_header_wrap_style_style-1.with_featured_image .post_header .post_meta_other {
  margin-top: 2.2em;
}

.post_header_wrap_style_style-1 .post_header .post_meta_other .post_meta_item:after,
.post_header_wrap_style_style-1 .post_header .post_meta_other .vc_inline-link:after {
  margin: 0 0.5em 0 0.74em;
}

.post_header_wrap_style_style-1 .post_header .post_meta_other .post_author_avatar {
  margin-right: 0.85em;
  margin-top: -3px;
}

.post_header_wrap_style_style-1 .post_header .post_meta_other .post_author_avatar > img {
  width: 32px;
  height: 32px;
  line-height: 32px;
  text-align: center;
}

.post_header_wrap_style_style-1 .before_post_header_banner_wrap + .post_featured.with_video {
  margin-top: 3em;
}
.post_header_wrap_style_style-1 .post_featured.with_video:not(.with_video_autoplay) + .post_header {
  margin-top: 2em;
}
.post_header_wrap_style_style-1 .post_featured.with_video.with_video_autoplay .video_frame {
  background-color: #000000;
}
.post_header_wrap_style_style-1 .post_featured.with_video.with_video_autoplay .video_frame video {
  object-fit: cover;
  height: 100%;
  max-height: 100%;
}

.single_style_style-1.single-format-audio .post_header_wrap_in_header:before {
  display: none;
}
.single_style_style-1.single-format-audio .post_header_wrap_in_header div.post_featured.with_thumb:after {
  display: block !important;
  background: rgba(0, 0, 0, 0.45);
}
.single_style_style-1.single-format-audio .post_featured.with_thumb + .post_header {
  top: calc( 50% - 30px );
}
.single_style_style-1.single-format-video .post_header_wrap_style_style-1 .post_featured.with_video_list {
  margin-bottom: 4em;
}

/* Video Popup Button */
.single-format-video .post_header_wrap_style_style-1 .post_featured.with_video.with_thumb.post_featured_bg:not(.with_video_autoplay) {
  position: static;
}
.single-format-video .post_header_wrap_style_style-1 .post_featured.with_video.with_thumb.post_featured_bg:not(.with_video_autoplay):after {
  display: none;
}
.single-format-video .post_header_wrap_style_style-1 .post_featured.with_video.with_thumb.post_featured_bg:not(.with_video_autoplay) + .post_header {
  padding-top: 20px;
  top: calc(50% + 50px);
}
.single-format-video .post_header_wrap_style_style-1 .post_featured.with_video.with_thumb.post_featured_bg:not(.with_video_autoplay) + .post_header .post_title {
  padding-bottom: 0.18em;
  overflow: hidden;
  display: -webkit-box;
  -webkit-line-clamp: 4;
  -webkit-box-orient: vertical;
}
.single-format-video .post_header_wrap_style_style-1 .post_featured.with_video.with_thumb.post_featured_bg:not(.with_video_autoplay) .post_video_hover {
  margin-top: -45vh;
  position: relative;
  z-index: 999;
  opacity: 0;
  -webkit-transition: color 0.3s ease, background-color 0.3s ease, opacity 0.3s ease-in-out;
  -ms-transition: color 0.3s ease, background-color 0.3s ease, opacity 0.3s ease-in-out;
  transition: color 0.3s ease, background-color 0.3s ease, opacity 0.3s ease-in-out;
  top: calc(50% - 60px);
}

.post_header_wrap_style_style-1 .post_featured.post_featured_bg.with_video.with_video_list {
  height: auto;
  background: none !important;
}
.post_header_wrap_style_style-1 .post_featured.post_featured_bg.with_video.with_video_list .wp-video {
  width: 100% !important;
}

.single_style_style-1.single-format-audio .post_header_wrap_in_header.with_featured_image .post_audio .post_info_audio {
  text-align: center;
  max-width: 50%;
  margin: 0 auto 30px;
}
.single_style_style-1.single-format-audio .post_header_wrap_in_header.with_featured_image .post_audio .post_info_audio .post_audio_author,
.single_style_style-1.single-format-audio .post_header_wrap_in_header.with_featured_image .post_audio .post_info_audio .post_audio_description,
.single_style_style-1.single-format-audio .post_header_wrap_in_header.with_featured_image .post_audio .post_info_audio .post_audio_title {
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.single_style_style-1.single-format-audio .post_header_wrap_in_header.with_featured_image .post_audio .post_info_audio .post_audio_description {
  margin-bottom: 0;
}
.single_style_style-1.single-format-audio .post_header_wrap_in_header.with_featured_image .post_audio .post_info_audio .post_audio_title {
  margin-bottom: 0.4em;
}
.single_style_style-1.single-format-audio .post_header_wrap_in_header .post_featured.without_thumb .post_audio {
  max-width: 70%;
  margin: 0 auto 3rem;
}
.single_style_style-1.single-format-audio .post_header_wrap_in_header .post_featured.without_thumb .post_audio .post_info_audio {
  max-width: 65%;
}
.single_style_style-1.single-format-audio.sidebar_hide.narrow_content .post_header_wrap_in_header.with_featured_image .post_audio .post_info_audio {
  max-width: 630px;
}

/*# sourceMappingURL=style-1.css.map */
