<?php
/**
 * The template to display default site header
 *
 * @package PANTRY
 * @since PANTRY 1.0
 */

$pantry_header_css   = '';
$pantry_header_image = get_header_image();
$pantry_header_video = pantry_get_header_video();
if ( ! empty( $pantry_header_image ) && pantry_trx_addons_featured_image_override( is_singular() || pantry_storage_isset( 'blog_archive' ) || is_category() ) ) {
	$pantry_header_image = pantry_get_current_mode_image( $pantry_header_image );
}

?><header class="top_panel top_panel_default
	<?php
	echo ! empty( $pantry_header_image ) || ! empty( $pantry_header_video ) ? ' with_bg_image' : ' without_bg_image';
	if ( '' != $pantry_header_video ) {
		echo ' with_bg_video';
	}
	if ( '' != $pantry_header_image ) {
		echo ' ' . esc_attr( pantry_add_inline_css_class( 'background-image: url(' . esc_url( $pantry_header_image ) . ');' ) );
	}
	if ( is_single() && has_post_thumbnail() ) {
		echo ' with_featured_image';
	}
	if ( pantry_is_on( pantry_get_theme_option( 'header_fullheight' ) ) ) {
		echo ' header_fullheight pantry-full-height';
	}
	$pantry_header_scheme = pantry_get_theme_option( 'header_scheme' );
	if ( ! empty( $pantry_header_scheme ) && ! pantry_is_inherit( $pantry_header_scheme  ) ) {
		echo ' scheme_' . esc_attr( $pantry_header_scheme );
	}
	?>
">
	<?php

	// Background video
	if ( ! empty( $pantry_header_video ) ) {
		get_template_part( apply_filters( 'pantry_filter_get_template_part', 'templates/header-video' ) );
	}

	// Main menu
	get_template_part( apply_filters( 'pantry_filter_get_template_part', 'templates/header-navi' ) );

	// Mobile header
	if ( pantry_is_on( pantry_get_theme_option( 'header_mobile_enabled' ) ) ) {
		get_template_part( apply_filters( 'pantry_filter_get_template_part', 'templates/header-mobile' ) );
	}

	// Page title and breadcrumbs area
	if ( ! is_single() ) {
		get_template_part( apply_filters( 'pantry_filter_get_template_part', 'templates/header-title' ) );
	}

	// Header widgets area
	get_template_part( apply_filters( 'pantry_filter_get_template_part', 'templates/header-widgets' ) );
	?>
</header>
