.sp-easy-accordion-faq-form-modal-overlay {
    position: fixed;
    top: 0;
    left: 0;
    width: 100%;
    height: 100%;
    background: rgba(0, 0, 0, 0.5);
    display: flex;
    align-items: center;
    justify-content: center;
    z-index: 1000;

    .sp-easy-accordion-faq-form-modal-content {
        position: relative;

        //close button
        .sp-easy-accordion-faq-form-modal-close-button {
            position: absolute;
            top: 10px;
            right: 10px;
            font-size: 28px;
            border: none;
            background: none;
            cursor: pointer;
        }

        .sp-easy-accordion-faq-form-modal-body {
            width: 100%;
        }
    }
}