<?php
if (!defined('ABSPATH')) die('No direct access allowed');
?>
<div class="updraft-exclude-panel-heading">
	<h3><?php echo esc_html($title);?></h3>
	<a href="#" class="updraft-exclude-modal-reset" style="display: inline;"><?php esc_html_e('Back...', 'updraftplus');?></a>
</div>
