<?php
/**
 * The template to display default site footer
 *
 * @package PANTRY
 * @since PANTRY 1.0.10
 */

?>
<footer class="footer_wrap footer_default
<?php
$pantry_footer_scheme = pantry_get_theme_option( 'footer_scheme' );
if ( ! empty( $pantry_footer_scheme ) && ! pantry_is_inherit( $pantry_footer_scheme  ) ) {
	echo ' scheme_' . esc_attr( $pantry_footer_scheme );
}
?>
				">
	<?php

	// Footer widgets area
	get_template_part( apply_filters( 'pantry_filter_get_template_part', 'templates/footer-widgets' ) );

	// Logo
	get_template_part( apply_filters( 'pantry_filter_get_template_part', 'templates/footer-logo' ) );

	// Socials
	get_template_part( apply_filters( 'pantry_filter_get_template_part', 'templates/footer-socials' ) );

	// Copyright area
	get_template_part( apply_filters( 'pantry_filter_get_template_part', 'templates/footer-copyright' ) );

	?>
</footer><!-- /.footer_wrap -->
