<?php
/**
 * The template to display custom header from the ThemeREX Addons Layouts
 *
 * @package PANTRY
 * @since PANTRY 1.0.06
 */

$pantry_header_css   = '';
$pantry_header_image = get_header_image();
$pantry_header_video = pantry_get_header_video();
if ( ! empty( $pantry_header_image ) && pantry_trx_addons_featured_image_override( is_singular() || pantry_storage_isset( 'blog_archive' ) || is_category() ) ) {
	$pantry_header_image = pantry_get_current_mode_image( $pantry_header_image );
}

$pantry_header_id = pantry_get_custom_header_id();
$pantry_header_meta = get_post_meta( $pantry_header_id, 'trx_addons_options', true );
if ( ! empty( $pantry_header_meta['margin'] ) ) {
	pantry_add_inline_css( sprintf( '.page_content_wrap{padding-top:%s}', esc_attr( pantry_prepare_css_value( $pantry_header_meta['margin'] ) ) ) );
}

?><header class="top_panel top_panel_custom top_panel_custom_<?php echo esc_attr( $pantry_header_id ); ?> top_panel_custom_<?php echo esc_attr( sanitize_title( get_the_title( $pantry_header_id ) ) ); ?>
				<?php
				echo ! empty( $pantry_header_image ) || ! empty( $pantry_header_video )
					? ' with_bg_image'
					: ' without_bg_image';
				if ( '' != $pantry_header_video ) {
					echo ' with_bg_video';
				}
				if ( '' != $pantry_header_image ) {
					echo ' ' . esc_attr( pantry_add_inline_css_class( 'background-image: url(' . esc_url( $pantry_header_image ) . ');' ) );
				}
				if ( is_single() && has_post_thumbnail() ) {
					echo ' with_featured_image';
				}
				if ( pantry_is_on( pantry_get_theme_option( 'header_fullheight' ) ) ) {
					echo ' header_fullheight pantry-full-height';
				}
				$pantry_header_scheme = pantry_get_theme_option( 'header_scheme' );
				if ( ! empty( $pantry_header_scheme ) && ! pantry_is_inherit( $pantry_header_scheme  ) ) {
					echo ' scheme_' . esc_attr( $pantry_header_scheme );
				}
				?>
">
	<?php

	// Background video
	if ( ! empty( $pantry_header_video ) ) {
		get_template_part( apply_filters( 'pantry_filter_get_template_part', 'templates/header-video' ) );
	}

	// Custom header's layout
	do_action( 'pantry_action_show_layout', $pantry_header_id );

	// Header widgets area
	get_template_part( apply_filters( 'pantry_filter_get_template_part', 'templates/header-widgets' ) );

	?>
</header>
