/* Blog layout: Excerpt 
------------------------- */
.post_layout_excerpt {
  position: relative;
  margin-bottom: 0;
}
.post_layout_excerpt .post_featured {
  margin-bottom: 1.75em;
}
.post_layout_excerpt .post-more-link {
  margin-top: 1.6em;
}
.post_layout_excerpt .swiper-pagination-bullets {
  display: none;
}
.post_layout_excerpt .slider_container.slider_controls_side .slider_controls_wrap > a,
.post_layout_excerpt .slider_outer_controls_side .slider_controls_wrap > a {
  opacity: 1;
  margin-left: 30px;
  margin-right: 30px;
}
.post_layout_excerpt blockquote + p {
  margin-top: 1em;
}
.post_layout_excerpt .post_meta {
  margin: 0;
}
.post_layout_excerpt .post_meta .post_categories,
.post_layout_excerpt .post_meta .post_sponsored_label {
  font-size: 12px;
  text-transform: uppercase;
  font-weight: 700;
  letter-spacing: 0.7px;
}
.post_layout_excerpt .post_meta .socials_share.socials_type_drop .social_items {
  right: auto;
  left: 0;
}
.post_layout_excerpt .post_meta .socials_share.socials_type_drop .social_items:before {
  right: auto;
  left: 20%;
}

.post_layout_excerpt + .post_layout_excerpt {
  margin-top: 2.6rem;
}
.fullpost_exist .post_layout_excerpt + .post_layout_excerpt {
  margin-top: 5rem;
}

.post_layout_excerpt.sticky {
  padding: 2em;
}

.post_layout_excerpt .post_featured {
  display: inline-block;
}

.post_layout_excerpt.post_format_audio .post_featured.without_thumb,
.post_layout_excerpt.post_format_gallery .post_featured.without_thumb {
  display: block;
}

.post_layout_excerpt .post_header {
  margin: 0;
  position: relative;
}

.post_layout_excerpt .post_header .post_price {
  width: auto;
  position: absolute;
  z-index: 1;
  top: 0;
  right: 0;
  font-size: 2.5em;
  line-height: 1.5em;
}

.post_layout_excerpt .post_category {
  margin-bottom: 0.5em;
}

.post_layout_excerpt .post_title {
  margin: 0;
}

.post_layout_excerpt .post_header + .post_content {
  margin-top: 1.1em;
}

.post_layout_excerpt .post_meta + .post_content_inner {
  margin-top: 0.95em;
}

.post_layout_excerpt .post_content p:last-child {
  margin-bottom: 0;
}

.post_layout_excerpt .post_title a {
  display: inline;
}

body:not(.blog_style_excerpt) .post_layout_excerpt {
  margin-bottom: 3em;
}

.post_layout_excerpt blockquote {
  margin: 0;
}

/*# sourceMappingURL=excerpt.css.map */
