@media (max-width: 1439px) {
  .post_layout_band .post_title {
    font-size: 24px;
  }

  .post_layout_band .post_content_wrap .post_category {
    margin-bottom: 0.7em;
  }
}
@media (max-width: 1279px) {
  /* Blog layout: Band */
  .post_layout_band .post_header .post_price {
    font-size: 1.5em;
    line-height: 1.5em;
  }
  .post_layout_band .post_content_wrap {
    padding: 2em;
  }
  .post_layout_band .post_title {
    font-size: 22px;
  }
  .post_layout_band .post_header + .post_content {
    margin-top: 0.7em;
  }
  .post_layout_band .post_content + .post_meta {
    margin-top: 17px;
  }
  .post_layout_band .post_content + .post_meta:before {
    margin-bottom: 16px;
  }
  .post_layout_band .post_content_wrap .post_category {
    margin-bottom: 0.6em;
  }
}
@media (max-width: 1023px) {
  /* Blog layout: Band */
}
@media (max-width: 767px) {
  /* Blog layout: Band */
  .post_layout_band {
    -webkit-flex-direction: column;
    -ms-flex-direction: column;
    flex-direction: column;
  }
  .post_layout_band .post_featured {
    -webkit-flex-basis: 100%;
    -ms-flex-basis: 100%;
    flex-basis: 100%;
  }
  .post_layout_band .post_featured + .post_content_wrap {
    -webkit-flex-basis: 100%;
    -ms-flex-basis: 100%;
    flex-basis: 100%;
  }
  .post_layout_band .post_header .post_price {
    position: static;
    right: auto;
    top: auto;
    margin-top: 0.3em;
  }

  .post_layout_band.post_format_audio .post_featured {
    width: 100%;
  }
  .post_layout_band.post_format_audio .post_featured.without_thumb .post_audio:not(.with_iframe) {
    padding: 2.5em 2.1em 0;
  }

  .post_layout_band.post_format_quote .post_content_wrap {
    padding: 36px 38px !important;
  }
}
@media (min-width: 641px) and (max-width: 767px) {
  .post_layout_band {
    -webkit-flex-direction: row;
    -ms-flex-direction: row;
    flex-direction: row;
  }
  .post_layout_band .post_featured {
    -webkit-flex-basis: 48%;
    -ms-flex-basis: 48%;
    flex-basis: 48%;
  }
  .post_layout_band .post_featured + .post_content_wrap {
    -webkit-flex-basis: 52%;
    -ms-flex-basis: 52%;
    flex-basis: 52%;
  }
  .post_layout_band .post_header .post_price {
    position: static;
    right: auto;
    top: auto;
    margin-top: 0.3em;
  }
}
@media (max-width: 479px) {
  /* Blog layout: Band */
  .post_layout_band .post_content_wrap {
    padding: 1.5em;
  }
  .post_layout_band .post_content_wrap .post_content_inner {
    line-height: 1.5em;
  }

  .post_layout_band .post_title {
    font-size: 20px;
    line-height: 24px;
  }

  .post_layout_band .post_content_wrap .post_category {
    margin-bottom: 0.4em;
  }

  .post_layout_band.post_format_audio .post_featured.without_thumb .post_audio:not(.with_iframe) {
    padding: 2.5em 1.5em 0;
  }

  .post_layout_band.post_format_quote .post_content_wrap {
    padding: 23px 24px !important;
  }
}

/*# sourceMappingURL=band-responsive.css.map */
