<?php // phpcs:ignore WordPress.Files.FileName.NotHyphenatedLowercase for backwards compatibility.

/**
 * Use the WooCommerce archive template for brand taxonomy pages
 *
 * @package WooCommerce\Templates
 * @version 9.4.0
 */

declare( strict_types = 1);

wc_get_template( 'archive-product.php' );
