@import "../../../../css/_mixins.scss";
@import "../../../../css/_theme-vars.scss";
@import "../../css/_skin-vars.scss";

@media #{$media_xl} {
	.post_layout_classic {
		padding-bottom: 10px;
	}
	body[class*="blog_style_classic"] .posts_container.columns_wrap {
		margin-bottom: calc(-1 * (var(--theme-var-grid_gap) + 10px));
	}
}

@media #{$media_lg} {
	/* Blog layout: Classic */
	.post_layout_classic {
		padding-bottom: 0;
	}
	body[class*="blog_style_classic"] .posts_container.columns_wrap {
		margin-bottom: calc(-1 * var(--theme-var-grid_gap));
	}
	.post_layout_classic .post_title {
		font-size: 22px;
		margin-top: 10px;
	}
	.post_layout_classic_4 .post_title {
		font-size: 20px;
	}
	
	.masonry_item .post_title {
		font-size: 22px;
	}
	.post_layout_classic-masonry_1 .post_title,
	.post_layout_classic-masonry_2 .post_title {
		font-size: 28px;
	}
	.masonry_wrap .masonry_item .post_layout_classic-masonry_1 .post_header,
	.masonry_wrap .masonry_item .post_layout_classic-masonry_2 .post_header,
	.masonry_wrap .masonry_item .post_layout_classic-masonry_3 .post_header {
		padding: 0 0 10px 50px;
	}
	.masonry_wrap .masonry_item .post_header {
		padding: 0 0 10px;
	}
	.masonry_wrap .masonry_item .post_featured {
		margin-bottom: 1.6em;
	}
	.masonry_wrap .masonry_item .format-audio .post_featured.without_thumb .post_audio:not(.with_iframe),
	.masonry_wrap .masonry_item .single-format-audio .post_featured.without_thumb .post_audio:not(.with_iframe),
	.masonry_wrap .masonry_item .sc_layouts_blog_item_featured .post_featured.without_thumb .post_audio:not(.with_iframe) {
		padding: 20px 25px;
	}
}

@media #{$media_md} {
	/* Blog layout: Classic */
	.post_layout_classic.post_format_audio .mejs-time {
		display:none;
	}
	.post_layout_classic .post_title {
		font-size: 22px;
		margin-top: 8px;
	}
	.post_layout_classic_3 .post_title {
		font-size: 20px;
	}
	.post_layout_classic_4 .post_title {
		font-size: 20px;
	}
	.classic_4 .column-1_4 {
		width: 50%;
	}
	.post_layout_classic .slider_container.slider_controls_side .slider_controls_wrap > a,
	.post_layout_classic .slider_outer_controls_side .slider_controls_wrap > a {
		margin-left: 10px;
		margin-right: 10px;
	}
}

@media #{$media_sm} {
	.post_layout_classic .post_title {
		font-size: 20px;
	}
	.post_layout_classic .post_header {
		padding: 0 0 10px;
	}
	body[class*="blog_style_classic"] .posts_container.columns_wrap {
		margin-bottom: calc(-1 * (var(--theme-var-grid_gap) + 10px));
	}
	.post_layout_classic .post_featured {
		margin-bottom: 1.1em;
	}
}

@media #{$media_xs} {
	.post_layout_classic .post_title {
		font-size: 18px;
		margin-top: 6px;
	}
}
